@@ -16,7 +16,7 @@
 
 import unittest
 
-from mock import patch
+from unittest.mock import patch
 
 from whatmaps.debianpkg import DebianPkg
 
