@@ -197,8 +197,8 @@ def main(argv):
     for pkg in pkgs:
         try:
             shared_objects += pkg.shared_objects
-        except PkgError:
-            logging.error("Cannot parse contents of %s - skipping it" % pkg.name)
+        except PkgError as e:
+            logging.error("%s - skipping package %s" % (e, pkg.name))
             ret = 1
     logging.debug("Found shared objects:")
     for so in shared_objects:
@@ -257,9 +257,6 @@ def main(argv):
 
 
 def run():
-    return(main(sys.argv))
-
-if __name__ == '__main__':
-    sys.exit(main(sys.argv))
+    return main(sys.argv)
 
 # vim:et:ts=4:sw=4:et:sts=4:ai:set list listchars=tab\:»·,trail\:·:
